#!/usr/bin/env python
# Test the speed of parsing a sample file - using: 
#
#  1) a regular expression
#  2) whitespace delimited text
#  3) fixed width text

import unittest, sys, os, re, datetime
import mx.TextTools as mxTextTools

import shottab.shotCreate

regStr = r"""
^\s*
(?P<shotNo>[+-]?\d+)           # Read an integer value into shotNo

\s+
(?P<day>[+-]?\d+)           # Read an integer value into day

\s+
(?P<hour>[+-]?\d+)           # Read an integer value into hour

\s+
(?P<min>[+-]?\d+)           # Read an integer value into min

\s+
(?P<sec>[+-]?\d+)           # Read an integer value into sec

\s+
(?P<nanosec>[+-]?\d+)           # Read an integer value into nanosec

\s+
(?P<lat>                     # Read a lat/long value
  (?:[+-]?\d+\s+[+-]?\d*\.\d*\s*[NESWnesw]?) |  # match an integer, whitespace,
                                               # a float (decimal minutes), opt. whitespace
                                               # and an optional direction (NESW), _OR_
  (?:[+-]?\d*\.\d*)              # match just a leading float value (decimal degrees)
)

\s+
(?P<lon>                     # Read a lat/long value
  (?:[+-]?\d+\s+[+-]?\d*\.\d*\s*[NESWnesw]?) |  # match an integer, whitespace,
                                               # a float (decimal minutes), opt. whitespace
                                               # and an optional direction (NESW), _OR_
  (?:[+-]?\d*\.\d*)              # match just a leading float value (decimal degrees)
)
"""

testLine = "1000		196	23	22	44	7677934	42	40.6718	N	62	22.8408	W	1.17*	000.00	2004	196	23	22	44	2	4	1"
testLoop = 10000
class SpeedTest(unittest.TestCase):
    def setUp(self):
        self.complexRegex = re.compile(regStr, re.IGNORECASE | re.VERBOSE)
        self.regSplitRegex = re.compile("[\s:,]*")
        self.findAllRegex = re.compile("([\S,:]+)\s*")
        self.before = datetime.datetime.today()
        
    def tearDown(self):
        after = datetime.datetime.today()
        diff = after - self.before
        print "test took: %d.%06d secs" % (diff.seconds, diff.microseconds)
        
    def testShottabRegexSpeed(self):
        for i in xrange(testLoop):
            result = self.complexRegex.match(testLine)
            
    def testPythonSplitSpeed(self):
        for i in xrange(testLoop):
            result = testLine.split()
            
    def testFixedSpeed(self):
        ranges = ((0, 10), (15, 25), (27, 30), (31, 33), (34, 35), (35, 40))
        for i in xrange(testLoop):
            for match in ranges:
                result = testLine[match[0] : match[1]].strip()
            
    def testRegexSplitSpeed(self):
        for i in xrange(testLoop):
            result = self.regSplitRegex.split(testLine)
            
    def testRegexFindAllSpeed(self):
        for i in xrange(testLoop):
            result = self.findAllRegex.findall(testLine)

    def testMxSplit(self):
        ws = mxTextTools.set(mxTextTools.whitespace + ".|,")
        for i in xrange(testLoop):
            # NOTE: can expand set by addint to the set below
            # _very_ extensible!
            mxTextTools.splitwords(testLine, whitespace_set=ws)
    
if __name__ == "__main__":
    unittest.main()
